@@ -1,5 +1,6 @@
 package Perlanet::Trait::Scrubber;
 
+use 5.10.0;
 use strict;
 use warnings;
 
@@ -102,6 +103,7 @@ sub _build_scrubber {
   my $scrub = HTML::Scrubber->new;
   $scrub->rules(%scrub_rules);
   $scrub->default(1, \%scrub_def);
+  $scrub->script(0);
 
   return $scrub;
 }
@@ -110,6 +112,9 @@ around 'clean_html' => sub {
   my $orig = shift;
   my $self = shift;
   my ($html) = @_;
+
+  warn __PACKAGE__, '::clean_html' if $ENV{PERLANET_DEBUG};
+
   $html = $self->$orig($html);
   my $scrubbed = $self->scrubber->scrub($html);
   return $scrubbed;
